@@ -38,7 +38,7 @@
 #              and not other keys.  Note that not all NXP processors
 #              including AHAB support this option.
 #
-#        Copyright 2018-2022 NXP
+#        Copyright 2018-2022, 2024 NXP
 #
 #
 #-----------------------------------------------------------------------------
@@ -62,8 +62,6 @@ printf "    All private keys in the PKI tree are in PKCS #8 format will be\n"
 printf "    protected by the same password.\n\n"
 printf "    +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++\n"
 
-stty erase 
-
 if [ $# -gt 0 ]; then
     interactive="n"
 else
@@ -277,8 +275,6 @@ fi
 # Compute validity period
 val_period=$((duration*365))
 
-# printf "How many Super Root Keys should be generated?  \b"
-# read num_srk
 num_srk=4
 
 # Check that 0 < num_srk <= 4 (Max. number of SRKs)
@@ -372,32 +368,54 @@ then
     echo +++++++++++++++++++++++++++++++++++++
     echo
 
-    if [ $use_ecc = 'n' ]
-    then
+if [ $use_ecc = 'n' ]
+then
         ca_key=./CA1_${da}_${kl}_65537_v3_ca_key
         ca_cert=../crts/CA1_${da}_${kl}_65537_v3_ca_crt
         ca_subj_req=/CN=CA1_${da}_${kl}_65537_v3_ca/
-        ca_key_type=rsa:${kl}
+
+    if [ $use_rsa_pss = 'y' ]
+    then
+        ca_key_type=rsa-pss
     else
-
-        # Generate Elliptic Curve parameters:
-        eck='ec-'$cn'.pem'
-        openssl ecparam -out $eck -name $cn
-
-        ca_key=./CA1_${da}_${cn}_v3_ca_key
-        ca_cert=../crts/CA1_${da}_${cn}_v3_ca_crt
-        ca_subj_req=/CN=CA1_${da}_${cn}_v3_ca/
-        ca_key_type=ec:${eck}
+        ca_key_type=rsa
     fi
+    openssl req -new \
+        -newkey ${ca_key_type} \
+        -keyout temp_ca.pem \
+        -out temp_ca_req.pem \
+        -pkeyopt rsa_keygen_bits:${kl} \
+        -passout file:./key_pass.txt \
+        -${da} \
+        -subj ${ca_subj_req}
+
+    openssl x509 -req \
+        -${da} \
+        -in temp_ca_req.pem \
+        -signkey temp_ca.pem \
+        -passin file:./key_pass.txt \
+        -out ${ca_cert}.pem \
+        -days ${val_period} \
+        -extensions v3_ca \
+        -extfile ../ca/openssl.cnf
+else
+    # Generate Elliptic Curve parameters:
+    eck='ec-'$cn'.pem'
+    openssl ecparam -out $eck -name $cn
+
+    ca_key=./CA1_${da}_${cn}_v3_ca_key
+    ca_cert=../crts/CA1_${da}_${cn}_v3_ca_crt
+    ca_subj_req=/CN=CA1_${da}_${cn}_v3_ca/
+    ca_key_type=ec:${eck}
 
     openssl req -newkey ${ca_key_type} -passout file:./key_pass.txt \
-                   -${da} \
-                   -subj ${ca_subj_req} \
-                   -x509 -extensions v3_ca \
-                   -keyout temp_ca.pem \
-                   -out ${ca_cert}.pem \
-                   -days ${val_period} -config ../ca/openssl.cnf
-
+                -${da} \
+                -subj ${ca_subj_req} \
+                -x509 -extensions v3_ca \
+                -keyout temp_ca.pem \
+                -out ${ca_cert}.pem \
+                -days ${val_period} -config ../ca/openssl.cnf
+fi
     # Generate CA key in PKCS #8 format - both PEM and DER
     openssl pkcs8 -passin file:./key_pass.txt -passout file:./key_pass.txt \
                   -topk8 -inform PEM -outform DER -v2 des3 \
